# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.models.pulp_export import PulpExport

class TestPulpExport(unittest.TestCase):
    """PulpExport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PulpExport:
        """Test PulpExport
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PulpExport`
        """
        model = PulpExport()
        if include_optional:
            return PulpExport(
                task = '',
                full = True,
                dry_run = True,
                versions = [
                    ''
                    ],
                chunk_size = '0',
                start_versions = [
                    ''
                    ]
            )
        else:
            return PulpExport(
        )
        """

    def testPulpExport(self):
        """Test PulpExport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
