# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi


class TestRepositoriesReclaimSpaceApi(unittest.TestCase):
    """RepositoriesReclaimSpaceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoriesReclaimSpaceApi()

    def tearDown(self) -> None:
        pass

    def test_reclaim(self) -> None:
        """Test case for reclaim

        """
        pass


if __name__ == '__main__':
    unittest.main()
